@@ -63,7 +63,9 @@ public abstract class LayersTestBase {
     public static final String[] NO_LAYER_WILDFLY_EE = {
             // In 'wildfly-ee' this is only a dep of org.apache.activemq.artemis.protocol.amqp,
             // which is not part of test-all-layers. It is used in a layer in 'wildfly' and 'wildfly-preview'
-            "org.apache.qpid.proton"
+            "org.apache.qpid.proton",
+            // 'preview' stability module so not yet included in "all-layers" installation
+            "jakarta.data.api"
     };
 
     /**
@@ -88,7 +90,11 @@ public abstract class LayersTestBase {
             "org.wildfly.extension.mvc-krazo",
             "jakarta.mvc.api",
             "org.eclipse.krazo.core",
-            "org.eclipse.krazo.resteasy"
+            "org.eclipse.krazo.resteasy",
+            // 'preview' stability extension so not yet included in
+            // the "all-layers" installation
+            "org.wildfly.extension.jakarta.data",
+            "jakarta.data.api",
     };
 
     /**
@@ -133,8 +139,6 @@ public abstract class LayersTestBase {
             "org.wildfly.security.elytron-tool",
             // bootable jar runtime
             "org.wildfly.bootable-jar",
-            // Extension not included in the default config
-            "org.wildfly.extension.clustering.singleton",
             // Dynamically added by ee-security and mp-jwt-smallrye DUPs but not referenced by subsystems.
             "org.wildfly.security.jakarta.security",
             // injected by sar
@@ -162,7 +166,7 @@ public abstract class LayersTestBase {
             "org.wildfly.extension.mod_cluster",
             "org.wildfly.mod_cluster.undertow",
             // Brought by galleon ServerRootResourceDefinition
-            "wildflyee.api"
+            "wildflyee.api",
     };
 
 
@@ -172,8 +176,6 @@ public abstract class LayersTestBase {
      */
     public static final String[] NOT_REFERENCED_WILDFLY_EE = {
             // Only injected by logging in 'wildfly-ee', but referenced in 'wildfly' and 'wildfly-preview'
-            "org.apache.logging.log4j.api",
-            "org.jboss.logmanager.log4j2",
     };
 
 
@@ -195,9 +197,9 @@ public abstract class LayersTestBase {
             // Extension not included in the default config
             "org.wildfly.extension.microprofile.lra-coordinator",
             "org.wildfly.extension.microprofile.lra-participant",
-            "org.jboss.narayana.rts.lra-service-base",
-            "org.jboss.narayana.rts.lra-coordinator",
-            "org.jboss.narayana.rts.lra-participant",
+            "org.jboss.narayana.lra.lra-service-base",
+            "org.jboss.narayana.lra.lra-coordinator",
+            "org.jboss.narayana.lra.lra-participant",
             "org.eclipse.microprofile.lra.api",
             // Extension not included in the default config
             "org.wildfly.extension.microprofile.openapi-smallrye",
@@ -241,6 +243,8 @@ public abstract class LayersTestBase {
             "jakarta.mvc.api",
             "org.eclipse.krazo.core",
             "org.eclipse.krazo.resteasy",
+            // 'preview' stability extension so not yet included in the standard configs
+            "org.wildfly.extension.jakarta.data",
     };
 
     /**
@@ -254,7 +258,8 @@ public abstract class LayersTestBase {
             "org.wildfly.extension.mvc-krazo",
             "jakarta.mvc.api",
             "org.eclipse.krazo.core",
-            "org.eclipse.krazo.resteasy"
+            "org.eclipse.krazo.resteasy",
+            "org.wildfly.extension.vertx"
     };
 
     /**
@@ -318,7 +323,10 @@ public abstract class LayersTestBase {
             "io.reactivex.rxjava2.rxjava",
             // Downstream uses this in installations provisioned with wildfly-ee but upstream does not.
             // To make life easier downstream we include it in wildfly-ee.
-            "com.fasterxml.jackson.dataformat.jackson-dataformat-yaml"
+            "com.fasterxml.jackson.dataformat.jackson-dataformat-yaml",
+            // 'preview' stability extension so not yet included in
+            // the "all-layers" installation or the standard configs
+            "org.wildfly.extension.jakarta.data"
     };
 
     /**
